@@ -6,6 +6,7 @@ interactive_table1 <- function(meta,
                                keep_missing = TRUE,
                                total = TRUE,
                                column_header = TRUE,
+                               show_listing = TRUE,
                                var_listing = NULL,
                                download = "none",
                                type = NULL,
@@ -31,6 +32,7 @@ interactive_table1 <- function(meta,
   if (!listing) {
     message("Drill-down listing is not provided because there are more than ", max_row, " rows in the datasets")
   }
+  listing <- show_listing & listing
 
   tbl <- metalite::collect_n_subject(meta,
     population = population,
@@ -42,6 +44,10 @@ interactive_table1 <- function(meta,
     display_total = total
   )
 
+  if(! is.null(tbl$listing)){
+    names(tbl$listing)[is.na(names(tbl$listing))] <- "Missing"
+  }
+
   # Display details in reactable
   details_ggplot2 <- function(index) {
     detail <- tbl$listing
