@@ -23,7 +23,7 @@
 #' @export
 metalite_table1 <- function(formula,
                             data,
-                            id,
+                            id = NULL,
                             var_listing = NULL,
                             total = TRUE,
                             header = NULL,
@@ -34,6 +34,14 @@ metalite_table1 <- function(formula,
     stop("There is no records in the input dataset")
   }
 
+  if(is.null(id)){
+    data$.id <- 1:nrow(data)
+    id = ".id"
+    show_listing <- FALSE
+  }else{
+    show_listing <- TRUE
+  }
+
   if (formula[[2]][[1]] == "|") {
     var <- all.vars(formula[[2]][[2]])
     group <- all.vars(formula[[2]][[3]])
@@ -112,6 +120,7 @@ metalite_table1 <- function(formula,
   htmltools::browsable(
     htmltools::tagList(metalite::meta_run(
       meta,
+      show_listing = show_listing,
       var_listing = var_listing,
       download = download,
       type = record_name
